.. _docs_fragment_plugins:

Docs fragments
==============

.. contents::
   :local:
   :depth: 2

Docs fragments allow you to document common parameters of multiple plugins or modules in a single place. 

.. _enabling_docs_fragments:

Enabling docs fragments
-----------------------

You can add a custom docs fragment by dropping it into a ``doc_fragments`` directory adjacent to your collection or role, just like any other plugin.

.. _using_docs_fragments:

Using docs fragments
--------------------

Only collection developers and maintainers use docs fragments. For more information on using docs fragments, see :ref:`module_docs_fragments` or :ref:`docfragments_collections`.

.. seealso::

   :ref:`developing_modules_general`
       An introduction to creating Ansible modules
   :ref:`developing_collections`
       An guide to creating Ansible collections
   `User Mailing List <https://groups.google.com/group/ansible-devel>`_
       Have a question?  Stop by the google group!
   :ref:`communication_irc`
       How to join Ansible chat channels
